@@ -39,7 +39,7 @@ MLT_REVISION=
 LOG_COLORS=0
 SHOTCUT_HEAD=1
 SHOTCUT_REVISION=
-SHOTCUT_VERSION=$(date '+%y.%m.%d')
+SHOTCUT_VERSION=$(date '+%y.%-m.%-d')
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
 BIGSH0T_REVISION="710e734512b8975722f0c41f793f28c51a3d2b88"
@@ -56,10 +56,12 @@ GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.10.0"
+OPENCV_REVISION="origin/4.x"
+OPENCV_CONTRIB_HEAD=0
+OPENCV_CONTRIB_REVISION="4.12.0"
 ENABLE_LIBSPATIALAUDIO=1
-LIBSPATIALAUDIO_HEAD=1
-LIBSPATIALAUDIO_REVISION=
+LIBSPATIALAUDIO_HEAD=0
+LIBSPATIALAUDIO_REVISION="origin/patch-1"
 ENABLE_LADSPA=1
 LADSPA_HEAD=0
 LADSPA_REVISION="origin/shotcut"
@@ -72,7 +74,7 @@ NV_CODEC_REVISION="sdk/12.0"
 PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
 PYTHON_VERSION_DLL=$(python3 --version | awk '{split($2, parts, "."); print parts[1]parts[2]}')
 
-QT_VERSION_X64="6.8.1"
+QT_VERSION_X64="6.9.2"
 
 ################################################################################
 # Location of config file - if not overridden on command line
@@ -451,7 +453,7 @@ function set_globals {
   REPOLOCS[14]="https://github.com/ddennedy/gopro2gpx.git"
   REPOLOCS[15]="https://github.com/opencv/opencv.git"
   REPOLOCS[16]="https://github.com/opencv/opencv_contrib.git"
-  REPOLOCS[17]="https://github.com/videolabs/libspatialaudio.git"
+  REPOLOCS[17]="https://github.com/ddennedy/libspatialaudio.git"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -530,12 +532,12 @@ function set_globals {
     REVISIONS[15]="$OPENCV_REVISION"
   fi
   REVISIONS[16]=""
-  if test 0 = "$OPENCV_HEAD" -a "$OPENCV_REVISION" ; then
-    REVISIONS[16]="$OPENCV_REVISION"
+  if test 0 = "$OPENCV_CONTRIB_HEAD" -a "$OPENCV_CONTRIB_REVISION" ; then
+    REVISIONS[16]="$OPENCV_CONTRIB_REVISION"
   fi
   REVISIONS[17]=""
   if test 0 = "$LIBSPATIALAUDIO_HEAD" -a "$LIBSPATIALAUDIO_REVISION" ; then
-    REVISIONS[17]="$LIBSPATIALAUDIO_REVISION_REVISION"
+    REVISIONS[17]="$LIBSPATIALAUDIO_REVISION"
   fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
@@ -581,7 +583,7 @@ function set_globals {
 
   #####
   # mlt
-  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_GDK=OFF -DMOD_GLAXNIMATE_QT6=ON -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_SDL1=OFF -DUSE_VST2=OFF"
+  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_GDK=OFF -DMOD_GLAXNIMATE_QT6=ON -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_SDL1=OFF -DUSE_VST2=OFF -DMOD_SPATIALAUDIO=ON"
   [ "$ENABLE_OPENCV" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_OPENCV=ON"
   if [ "$DEBUG_BUILD" = "1" ]; then
     CONFIG[1]="${CONFIG[1]} -DCMAKE_BUILD_TYPE=RelWithDebInfo"
@@ -646,7 +648,12 @@ function set_globals {
 
   #####
   # whisper.cpp
-  CONFIG[9]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -D GGML_AVX2=OFF -D GGML_BLAS=ON -D GGML_BLAS_VENDOR=OpenBLAS -D BUILD_SHARED_LIBS=ON -D GGML_NATIVE=OFF -D WHISPER_BUILD_SERVER=OFF -D WHISPER_BUILD_TESTS=OFF"
+  CONFIG[9]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -D BUILD_SHARED_LIBS=ON -D GGML_NATIVE=OFF -D WHISPER_BUILD_SERVER=OFF -D WHISPER_BUILD_TESTS=OFF"
+  if [ "$TARGET_ARCH" = "clangarm64" ]; then
+    CONFIG[9]="${CONFIG[9]} -D GGML_BLAS=OFF"
+  else
+    CONFIG[9]="${CONFIG[9]} -D GGML_AVX2=OFF -D GGML_BLAS=ON -D GGML_BLAS_VENDOR=OpenBLAS"
+  fi
   CFLAGS_[9]=$CFLAGS
   LDFLAGS_[9]=$LDFLAGS
   BUILD[9]="ninja -C build -j $MAKEJ"
@@ -691,7 +698,7 @@ function set_globals {
   # glaxnimate
   CONFIG[13]="cmake -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D Python3_FIND_REGISTRY=NEVER"
   if [ "$TARGET_ARCH" = "clangarm64" ]; then
-    CONFIG[13]="${CONFIG[13]} -D CMAKE_PREFIX_PATH=$FINAL_INSTALL_DIR"
+    CONFIG[13]="${CONFIG[13]} -D CMAKE_CXX_FLAGS=-DPYBIND11_EXPORT_EXCEPTION= -D CMAKE_PREFIX_PATH=$FINAL_INSTALL_DIR"
   else
     CONFIG[13]="${CONFIG[13]} -D CMAKE_PREFIX_PATH=$QTDIR"
   fi
@@ -718,7 +725,7 @@ function set_globals {
   CONFIG[15]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D BUILD_LIST=tracking -D OPENCV_GENERATE_PKGCONFIG=YES -D OPENCV_EXTRA_MODULES_PATH=../opencv_contrib/modules -D WITH_OPENMP=ON $CMAKE_DEBUG_FLAG"
   CFLAGS_[15]="$CFLAGS"
   LDFLAGS_[15]="$LDFLAGS"
-  BUILD[15]="build_opencv"
+  BUILD[15]="ninja -C build -j $MAKEJ"
   INSTALL[15]="ninja -C build install"
 
   #####
@@ -735,11 +742,6 @@ function build_dav1d {
   cmd ninja -C builddir -j $MAKEJ || cmd ninja -C builddir -j $MAKEJ
 }
 
-function build_opencv {
-  [ grep M_PI 3rdparty/carotene/include/carotene/definitions.hpp ] || printf >>3rdparty/carotene/include/carotene/definitions.hpp '#ifndef M_PI\n#define M_PI (3.14159265358979323846)\n#endif'
-  cmd ninja -C build -j $MAKEJ
-}
-
 function install_amf {
   cmd rm -rf Thirdparty
   cmd mkdir -p "$FINAL_INSTALL_DIR/include/AMF"
@@ -774,8 +776,6 @@ function install_spatialaudio {
 function install_whispercpp {
   cmd ninja -C build install
   cmd install -p -c build/bin/whisper-cli.exe $FINAL_INSTALL_DIR/bin
-  cmd mkdir -p $FINAL_INSTALL_DIR/share/shotcut/whisper_models
-  cmd install -p -c models/ggml-base-q5_1.bin $FINAL_INSTALL_DIR/share/shotcut/whisper_models
 }
 
 ######################################################################
@@ -982,10 +982,6 @@ function get_subproject {
       cmd cd $1 || die "Unable to change to directory $1"
   fi # git/svn
 
-  if [ "$1" = "whisper.cpp" ]; then
-    cmd sh ./models/download-ggml-model.sh base-q5_1
-  fi
-
   feedback_status Done getting or updating source for $1
   cmd popd
 }
@@ -1262,7 +1258,7 @@ function deploy
   log Copying some libs from msys2
   cmd cp -p /${TARGET_ARCH}/bin/libcrypto-3.dll .
   if [ "$TARGET_ARCH" = "clangarm64" ]; then
-    cmd cp -p /${TARGET_ARCH}/bin/{libjasper.dll,libjpeg-8.dll,libmng-2.dll,liblcms2-2.dll,libtiff-6.dll,libjbig-0.dll,libdeflate.dll,libLerc.dll,libunwind.dll,libwebpdemux-2.dll,libcairo-2.dll,libfontconfig-1.dll,libpixman-1-0.dll,libxml2-2.dll,libomp.dll,libebur128.dll,libsamplerate-0.dll,librubberband-2.dll,libsox-3.dll,libopencore-amrnb-0.dll,libvo-amrwbenc-0.dll,libFLAC.dll,libltdl-7.dll,libgsm.dll,libmad-0.dll,libao-4.dll,libid3tag-0.dll,libtwolame-0.dll,libvorbisfile-3.dll,libwavpack-1.dll,libsndfile-1.dll,libopencore-amrwb-0.dll,libmpg123-0.dll,libopusfile-0.dll,libmysofa.dll,libvidstab.dll,libexpat-1.dll,liblz4.dll,libfftw3f-3.dll} .
+    cmd cp -p /${TARGET_ARCH}/bin/{libjasper.dll,libjpeg-8.dll,libmng-2.dll,liblcms2-2.dll,libtiff-6.dll,libjbig-0.dll,libdeflate.dll,libLerc.dll,libunwind.dll,libwebpdemux-2.dll,libcairo-2.dll,libfontconfig-1.dll,libpixman-1-0.dll,libxml2-16.dll,libomp.dll,libebur128.dll,libsamplerate-0.dll,librubberband-2.dll,libsox-3.dll,libopencore-amrnb-0.dll,libvo-amrwbenc-0.dll,libFLAC.dll,libltdl-7.dll,libgsm.dll,libmad-0.dll,libao-4.dll,libid3tag-0.dll,libtwolame-0.dll,libvorbisfile-3.dll,libwavpack-1.dll,libsndfile-1.dll,libopencore-amrwb-0.dll,libmpg123-0.dll,libopusfile-0.dll,libmysofa.dll,libvidstab.dll,libexpat-1.dll,liblz4.dll,libfftw3f-3.dll} .
   fi
   if [ "$DEBUG_BUILD" = "1" -o "$SDK" = "1" ]; then
     [ "$TARGET_ARCH" != "clangarm64" ] && cmd cp -p "$SOURCE_DIR"/shotcut/drmingw/x64/bin/*.{dll,yes} .
