@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2024 Meltytech, LLC
+ * Copyright (c) 2014-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -142,7 +142,6 @@ QmlMetadata *FilterController::metadata(const QString &id)
 
 QmlMetadata *FilterController::metadataForService(Mlt::Service *service)
 {
-    QmlMetadata *meta = nullptr;
     QString uniqueId = service->get(kShotcutFilterProperty);
 
     // Fallback to mlt_service for legacy filters
@@ -274,6 +273,16 @@ void FilterController::setCurrentFilter(int attachedIndex)
     }
 }
 
+void FilterController::onGainChanged()
+{
+    if (m_currentFilter) {
+        QString name = m_currentFilter->objectNameOrService();
+        if (name == QStringLiteral("audioGain")) {
+            emit m_currentFilter->changed();
+        }
+    }
+}
+
 void FilterController::onFadeInChanged()
 {
     if (m_currentFilter) {
@@ -422,3 +431,17 @@ void FilterController::addOrEditFilter(Mlt::Filter *filter, const QStringList &k
     }
     setCurrentFilter(serviceIndex);
 }
+
+void FilterController::setTrackTransitionService(const QString &service)
+{
+    if (service == QStringLiteral("qtblend")) {
+        m_metadataModel.setHidden("qtBlendMode", false);
+        m_metadataModel.setHidden("blendMode", true);
+    } else if (service == QStringLiteral("frei0r.cairoblend")) {
+        m_metadataModel.setHidden("qtBlendMode", true);
+        m_metadataModel.setHidden("blendMode", false);
+    } else {
+        m_metadataModel.setHidden("qtBlendMode", true);
+        m_metadataModel.setHidden("blendMode", true);
+    }
+}
