@@ -239,7 +239,7 @@ public:
                 tr("Image"),
                 tr("Audio"),
                 tr("Other"),
-                QStringLiteral(""),
+                QLatin1String(""),
             };
             auto i = isDir ? 4 : mediaType(index);
             return names[i];
@@ -501,20 +501,20 @@ FilesDock::FilesDock(QWidget *parent)
     const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
     ui->locationsCombo->addItem(tr("Home", "The user's home folder in the file system"), ls.first());
     ui->locationsCombo->addItem(tr("Current Project"), "");
-    ui->locationsCombo
-        ->addItem(tr("Documents"),
-                  QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation).first());
+    ui->locationsCombo->addItem(tr("Documents"),
+                                QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation)
+                                    .constFirst());
 #if defined(Q_OS_MAC)
     ui->locationsCombo
         ->addItem(tr("Movies", "The system-provided videos folder called Movies on macOS"),
-                  QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first());
+                  QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).constFirst());
 #endif
     ui->locationsCombo
         ->addItem(tr("Music"),
-                  QStandardPaths::standardLocations(QStandardPaths::MusicLocation).first());
+                  QStandardPaths::standardLocations(QStandardPaths::MusicLocation).constFirst());
     ui->locationsCombo
         ->addItem(tr("Pictures", "The system-provided photos folder"),
-                  QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first());
+                  QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).constFirst());
 #if defined(Q_OS_MAC)
     ui->locationsCombo->addItem(
         tr("Volumes",
@@ -623,19 +623,34 @@ FilesDock::FilesDock(QWidget *parent)
     toolbar->addAction(Actions["filesViewTilesAction"]);
     toolbar->addAction(Actions["filesViewIconsAction"]);
     toolbar->addSeparator();
-    toolbar->addAction(Actions["filesGoUp"]);
-    toolbar->addSeparator();
     m_label = new QLabel(toolbar);
     toolbar->addWidget(m_label);
-    connect(m_filesModel, &QAbstractItemModel::rowsInserted, this, &FilesDock::updateStatus);
-    connect(m_filesModel, &QFileSystemModel::directoryLoaded, this, &FilesDock::updateStatus);
+    connect(m_filesModel,
+            &QFileSystemModel::directoryLoaded,
+            this,
+            &FilesDock::updateStatus,
+            Qt::QueuedConnection);
+    connect(m_filesProxyModel,
+            &QAbstractItemModel::modelAboutToBeReset,
+            this,
+            &FilesDock::clearStatus);
+    connect(m_filesProxyModel, &QAbstractItemModel::rowsInserted, this, &FilesDock::updateStatus);
+    connect(m_filesProxyModel, &QAbstractItemModel::rowsRemoved, this, &FilesDock::updateStatus);
     ui->verticalLayout->addWidget(toolbar);
     ui->verticalLayout->addSpacing(2);
 
     toolbar = new DockToolBar(tr("Files Filters"));
+    toolbar->setAreaHint(Qt::BottomToolBarArea);
     toolbar->addAction(Actions["filesFoldersView"]);
     ui->filtersLayout->addWidget(toolbar);
 
+    toolbar = new DockToolBar(ui->label->text());
+    toolbar->setAreaHint(Qt::BottomToolBarArea);
+    toolbar->addAction(Actions["filesRefreshFolders"]);
+    toolbar->addAction(Actions["filesGoUp"]);
+    delete ui->label;
+    ui->locationsLayout->insertWidget(1, toolbar);
+
     auto toolbar2 = new QToolBar(tr("Files Filters"));
     QString styleSheet = QStringLiteral("QToolButton {"
                                         "    background-color: palette(background);"
@@ -737,7 +752,6 @@ FilesDock::FilesDock(QWidget *parent)
     } else { /* if (Settings.filesViewMode() == kIconsMode) */
         Actions["filesViewIconsAction"]->trigger();
     }
-    addOpenWithMenu(m_mainMenu);
     Actions.loadFromMenu(m_mainMenu);
 
     LOG_DEBUG() << "end";
@@ -1134,7 +1148,6 @@ void FilesDock::changeFilesDirectory(const QModelIndex &index)
     ui->locationsCombo->setCurrentText(path);
     ui->locationsCombo->setToolTip(path);
     m_view->scrollToTop();
-    clearStatus();
 }
 
 void FilesDock::viewCustomContextMenuRequested(const QPoint &pos)
@@ -1232,7 +1245,7 @@ void FilesDock::onSelectAllActionTriggered()
 
 void FilesDock::onUpdateThumbnailsActionTriggered()
 {
-    for (const auto &index : m_view->selectionModel()->selectedIndexes()) {
+    for (auto &index : m_view->selectionModel()->selectedIndexes()) {
         auto sourceIndex = m_filesProxyModel->mapToSource(index);
         if (sourceIndex.isValid())
             m_filesModel->updateThumbnails(sourceIndex);
@@ -1261,20 +1274,7 @@ void FilesDock::onOpenOtherAdd()
     if (filePath.isEmpty())
         return;
 
-    QString dir("/usr/bin");
-    QString filter;
-#if defined(Q_OS_WIN)
-    dir = QStringLiteral("C:/Program Files");
-    filter = tr("Executable Files (*.exe);;All Files (*)");
-#elif defined(Q_OS_MAC)
-    dir = QStringLiteral("/Applications");
-#endif
-    const auto program = QFileDialog::getOpenFileName(MAIN.window(),
-                                                      tr("Choose Executable"),
-                                                      dir,
-                                                      filter,
-                                                      nullptr,
-                                                      Util::getFileDialogOptions());
+    const auto program = Util::getExecutable(&MAIN);
     if (!program.isEmpty()) {
         if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
             Settings.setFilesOpenOther(firstSelectedMediaType(), program);
@@ -1294,7 +1294,7 @@ void FilesDock::onOpenOtherRemove()
     });
     ListSelectionDialog dialog(programs, this);
     dialog.setWindowModality(QmlApplication::dialogModality());
-    dialog.setWindowTitle(tr("Remove From Open Other"));
+    dialog.setWindowTitle(tr("Remove From Open With"));
     if (QDialog::Accepted == dialog.exec()) {
         for (auto program : dialog.selection()) {
             program = QDir::fromNativeSeparators(program);
@@ -1312,9 +1312,10 @@ void FilesDock::clearStatus()
 
 void FilesDock::updateStatus()
 {
-    auto n = m_filesModel->rowCount(m_filesModel->index(m_filesModel->rootPath()));
+    if (!m_view->rootIndex().isValid())
+        return;
+    auto n = m_filesProxyModel->rowCount(m_view->rootIndex());
     m_label->setText(tr("%n item(s)", nullptr, n));
-    QCoreApplication::processEvents();
 }
 
 void FilesDock::onLocationsEditingFinished()
@@ -1330,7 +1331,7 @@ void FilesDock::onLocationsEditingFinished()
     changeDirectory(path);
 }
 
-void FilesDock::on_locationsCombo_activated(int index)
+void FilesDock::on_locationsCombo_activated(int)
 {
     auto path = ui->locationsCombo->currentData().toString();
     if (path.isEmpty() && !MAIN.fileName().isEmpty())
