@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Meltytech, LLC
+ * Copyright (c) 2012-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,18 +19,23 @@
 #define ENCODEJOB_H
 
 #include "meltjob.h"
+
 #include <QThread>
 
 class EncodeJob : public MeltJob
 {
     Q_OBJECT
 public:
-    EncodeJob(const QString &name, const QString &xml, int frameRateNum, int frameRateDen,
+    EncodeJob(const QString &name,
+              const QString &xml,
+              int frameRateNum,
+              int frameRateDen,
               const QThread::Priority priority);
 
 private slots:
     void onVideoQualityTriggered();
     void onSpatialMediaTriggered();
+    void onEmbedChapters();
 
 protected slots:
     void onFinished(int exitCode, QProcess::ExitStatus exitStatus);
