@@ -370,12 +370,6 @@ int main(int argc, char **argv)
         qputenv("QT_MEDIA_BACKEND", "windows");
     if (!qEnvironmentVariableIsSet("QT_QPA_PLATFORM"))
         qputenv("QT_QPA_PLATFORM", "windows:altgr");
-
-    // The modern Windows style adopted in Qt 6.7 changes spinboxes to have
-    // larger arrow buttons side-by-side thus making the numeric area
-    // smaller and incompatible with every other combination of style and OS.
-    if (!qEnvironmentVariableIsSet("QT_STYLE_OVERRIDE"))
-        qputenv("QT_STYLE_OVERRIDE", "windowsvista");
 #else
         ;
 #endif
@@ -489,6 +483,7 @@ int main(int argc, char **argv)
 
         if (EXIT_RESTART == result || EXIT_RESET == result) {
             LOG_DEBUG() << "restarting app";
+            ::qunsetenv("QT_QUICK_CONTROLS_CONF"); // See MainWindow::changeTheme()
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
             ::qputenv("LIBGL_ALWAYS_SOFTWARE",
                       Settings.drawMethod() == Qt::AA_UseSoftwareOpenGL && !Settings.playerGPU()
