@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2024 Meltytech, LLC
+ * Copyright (c) 2014-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -241,6 +241,7 @@ void MltXmlChecker::processProperties()
         checkUnlinkedFile(mlt_service);
         checkIncludesSelf(newProperties);
         checkLumaAlphaOver(mlt_service, newProperties);
+        checkAudioGain(mlt_service, newProperties);
 #if LIBMLT_VERSION_INT >= ((6 << 16) + (23 << 8))
         replaceWebVfxCropFilters(mlt_service, newProperties);
         replaceWebVfxChoppyFilter(mlt_service, newProperties);
@@ -434,7 +435,8 @@ void MltXmlChecker::checkGpuEffects(const QString &mlt_service)
 
 void MltXmlChecker::checkCpuEffects(const QString &mlt_service)
 {
-    if (mlt_service.startsWith("frei0r.cairoblend") || mlt_service.startsWith("choppy"))
+    if (mlt_service.startsWith("qtblend") || mlt_service.startsWith("frei0r.cairoblend")
+        || mlt_service.startsWith("choppy"))
         m_needsCPU = true;
 }
 
@@ -536,6 +538,22 @@ void MltXmlChecker::checkIncludesSelf(QVector<MltProperty> &properties)
     }
 }
 
+void MltXmlChecker::checkAudioGain(const QString &mlt_service, QVector<MltProperty> &properties)
+{
+    if (mlt_service == "volume") {
+        bool found = false;
+        for (auto &p : properties) {
+            if (p.first == kShotcutFilterProperty) {
+                found = true;
+            }
+        }
+        if (!found) {
+            properties << MltProperty(kShotcutFilterProperty, "audioGain");
+            m_isUpdated = true;
+        }
+    }
+}
+
 void MltXmlChecker::checkLumaAlphaOver(const QString &mlt_service,
                                        QVector<MltXmlChecker::MltProperty> &properties)
 {
