@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2024 Meltytech, LLC
+ * Copyright (c) 2012-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,10 +18,11 @@
 #ifndef PLAYER_H
 #define PLAYER_H
 
-#include <QWidget>
+#include "sharedframe.h"
+
 #include <QIcon>
 #include <QSize>
-#include "sharedframe.h"
+#include <QWidget>
 
 class DockToolBar;
 class ScrubBar;
@@ -48,10 +49,7 @@ class Player : public QWidget
 {
     Q_OBJECT
 public:
-    typedef enum {
-        SourceTabIndex = 0,
-        ProjectTabIndex
-    } TabIndex;
+    typedef enum { SourceTabIndex = 0, ProjectTabIndex } TabIndex;
 
     explicit Player(QWidget *parent = 0);
     void connectTransport(const TransportControllable *);
@@ -59,14 +57,8 @@ public:
     void setOut(int);
     void setMarkers(const QList<int> &);
     QSize videoSize() const;
-    int position() const
-    {
-        return m_position;
-    }
-    NewProjectFolder *projectWidget() const
-    {
-        return m_projectWidget;
-    }
+    int position() const { return m_position; }
+    NewProjectFolder *projectWidget() const { return m_projectWidget; }
     void moveVideoToScreen(int screen = -1);
     void setPauseAfterOpen(bool pause);
     TabIndex tabIndex() const;
@@ -94,6 +86,7 @@ signals:
     void trimIn();
     void trimOut();
     void loopChanged(int start, int end);
+    void toggleVuiRequested();
 
 public slots:
     void play(double speed = 1.0);
@@ -113,11 +106,15 @@ public slots:
     void switchToTab(TabIndex index);
     void enableTab(TabIndex index, bool enabled = true);
     void onTabBarClicked(int index);
-    void setStatusLabel(const QString &text, int timeoutSeconds, QAction *action,
+    void setStatusLabel(const QString &text,
+                        int timeoutSeconds,
+                        QAction *action,
                         QPalette::ColorRole role = QPalette::ToolTipBase);
     void showIdleStatus();
     void focusPositionSpinner() const;
     void onMuteButtonToggled(bool checked);
+    void nextFrame();
+    void previousFrame();
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
@@ -130,6 +127,7 @@ private:
     double setVolume(int volume);
     void setLoopRange(int start, int end);
     void layoutToolbars();
+    void seekBy(int frames);
 
     ScrubBar *m_scrubber;
     TimeSpinBox *m_positionSpinner;
@@ -177,6 +175,7 @@ private:
     DockToolBar *m_inSelectedToolBar;
     QHBoxLayout *m_toolRow1;
     QHBoxLayout *m_toolRow2;
+    int m_requestedPosition{0};
 
 private slots:
     void updateSelection();
