@@ -606,6 +606,16 @@ void ShotcutSettings::setPlayerJACK(bool b)
     settings.setValue("player/jack", b);
 }
 
+int ShotcutSettings::playerDecklinkGamma() const
+{
+    return settings.value("player/decklinkGamma", 0).toInt();
+}
+
+void ShotcutSettings::setPlayerDecklinkGamma(int i)
+{
+    settings.setValue("player/decklinkGamma", i);
+}
+
 int ShotcutSettings::playerKeyerMode() const
 {
     return settings.value("player/keyer", 0).toInt();
@@ -954,6 +964,17 @@ void ShotcutSettings::setTimelineRectangleSelect(bool b)
     emit timelineRectangleSelectChanged();
 }
 
+bool ShotcutSettings::timelineAdjustGain() const
+{
+    return settings.value("timeline/adjustGain", true).toBool();
+}
+
+void ShotcutSettings::setTimelineAdjustGain(bool b)
+{
+    settings.setValue("timeline/adjustGain", b);
+    emit timelineAdjustGainChanged();
+}
+
 QString ShotcutSettings::filterFavorite(const QString &filterName)
 {
     return settings.value("filter/favorite/" + filterName, "").toString();
@@ -1391,14 +1412,24 @@ QList<QKeySequence> ShotcutSettings::shortcuts(const QString &name)
     return shortcuts;
 }
 
-double ShotcutSettings::slideshowClipDuration(double defaultClipDuration) const
+double ShotcutSettings::slideshowImageDuration(double defaultSeconds) const
 {
-    return settings.value("slideshow/clipDuration", defaultClipDuration).toDouble();
+    return settings.value("slideshow/clipDuration", defaultSeconds).toDouble();
 }
 
-void ShotcutSettings::setSlideshowClipDuration(double clipDuration)
+void ShotcutSettings::setSlideshowImageDuration(double seconds)
 {
-    settings.setValue("slideshow/clipDuration", clipDuration);
+    settings.setValue("slideshow/clipDuration", seconds);
+}
+
+double ShotcutSettings::slideshowAudioVideoDuration(double defaultSeconds) const
+{
+    return settings.value("slideshow/audioVideoDuration", defaultSeconds).toDouble();
+}
+
+void ShotcutSettings::setSlideshowAudioVideoDuration(double seconds)
+{
+    settings.setValue("slideshow/audioVideoDuration", seconds);
 }
 
 int ShotcutSettings::slideshowAspectConversion(int defaultAspectConversion) const
@@ -1517,8 +1548,7 @@ QString ShotcutSettings::whisperModel()
 {
     QDir dataPath = QmlApplication::dataDir();
     dataPath.cd("shotcut/whisper_models");
-    return settings.value("subtitles/whisperModel", dataPath.absoluteFilePath("ggml-base-q5_1.bin"))
-        .toString();
+    return settings.value("subtitles/whisperModel", "").toString();
 }
 
 void ShotcutSettings::setNotesZoom(int zoom)
@@ -1568,3 +1598,13 @@ void ShotcutSettings::setTimeFormat(int format)
     settings.setValue("timeFormat", format);
     emit timeFormatChanged();
 }
+
+bool ShotcutSettings::askFlatpakWrappers()
+{
+    return settings.value("flatpakWrappers", true).toBool();
+}
+
+void ShotcutSettings::setAskFlatpakWrappers(bool b)
+{
+    settings.setValue("flatpakWrappers", b);
+}
