@@ -75,6 +75,8 @@ class ShotcutSettings : public QObject
                    setTimelineRectangleSelect NOTIFY timelineRectangleSelectChanged)
     Q_PROPERTY(bool keyframesDragScrub READ keyframesDragScrub WRITE setKeyframesDragScrub NOTIFY
                    keyframesDragScrubChanged)
+    Q_PROPERTY(bool timelineAdjustGain READ timelineAdjustGain WRITE setTimelineAdjustGain NOTIFY
+                   timelineAdjustGainChanged)
 
 public:
     static const qsizetype MaxPath{32767};
@@ -153,6 +155,8 @@ public:
     void setPlayerInterpolation(const QString &);
     bool playerJACK() const;
     void setPlayerJACK(bool);
+    int playerDecklinkGamma() const;
+    void setPlayerDecklinkGamma(int);
     int playerKeyerMode() const;
     void setPlayerKeyerMode(int);
     bool playerMuted() const;
@@ -221,6 +225,8 @@ public:
     void setTimelineAutoAddTracks(bool);
     bool timelineRectangleSelect() const;
     void setTimelineRectangleSelect(bool);
+    bool timelineAdjustGain() const;
+    void setTimelineAdjustGain(bool);
 
     // filter
     QString filterFavorite(const QString &filterName);
@@ -298,6 +304,8 @@ public:
     void setBackupPeriod(int i);
     mlt_time_format timeFormat() const;
     void setTimeFormat(int format);
+    bool askFlatpakWrappers();
+    void setAskFlatpakWrappers(bool b);
 
     // proxy
     bool proxyEnabled() const;
@@ -315,8 +323,10 @@ public:
     QList<QKeySequence> shortcuts(const QString &name);
 
     // Slideshow
-    double slideshowClipDuration(double defaultClipDuration) const;
-    void setSlideshowClipDuration(double clipDuration);
+    double slideshowImageDuration(double defaultSeconds) const;
+    void setSlideshowImageDuration(double seconds);
+    double slideshowAudioVideoDuration(double defaultSeconds) const;
+    void setSlideshowAudioVideoDuration(double seconds);
     int slideshowAspectConversion(int defaultAspectConversion) const;
     void setSlideshowAspectConversion(int aspectConversion);
     int slideshowZoomPercent(int defaultZoomPercent) const;
@@ -396,6 +406,7 @@ signals:
     void timelineRectangleSelectChanged();
     void timeFormatChanged();
     void keyframesDragScrubChanged();
+    void timelineAdjustGainChanged();
 
 private:
     explicit ShotcutSettings();
