@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2024 Meltytech, LLC
+ * Copyright (c) 2014-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 
 #include "util.h"
 
+#include "FlatpakWrapperGenerator.h"
 #include "Logger.h"
 #include "dialogs/transcodedialog.h"
 #include "mainwindow.h"
@@ -41,6 +42,7 @@
 #include <QMediaDevices>
 #include <QMessageBox>
 #include <QProcess>
+#include <QStandardPaths>
 #include <QStorageInfo>
 #include <QStringList>
 #include <QTemporaryFile>
@@ -386,7 +388,8 @@ void Util::applyCustomProperties(Mlt::Producer &destination, Mlt::Producer &sour
         "force_aspect_ratio, video_delay, color_range, warp_speed, warp_pitch, "
         "rotate," kAspectRatioNumerator "," kAspectRatioDenominator "," kCommentProperty
         "," kShotcutProducerProperty "," kDefaultAudioIndexProperty "," kOriginalInProperty
-        "," kOriginalOutProperty "," kOriginalResourceProperty "," kDisableProxyProperty);
+        "," kOriginalOutProperty "," kOriginalResourceProperty "," kDisableProxyProperty
+        "," kShotcutBinsProperty);
     if (!destination.get("_shotcut:resource")) {
         destination.set("_shotcut:resource", destination.get("resource"));
         destination.set("_shotcut:length", destination.get("length"));
@@ -799,7 +802,7 @@ QString Util::trcString(int trc)
 bool Util::trcIsCompatible(int trc)
 {
     // Transfer characteristics > SMPTE240M Probably need conversion except IEC61966-2-4 is OK
-    return trc <= 7 || trc == 11 || trc == 13 || trc == 18;
+    return trc <= 7 || trc == 11 || trc == 13 || trc == 14 || trc == 15 || trc == 18;
 }
 
 QString Util::getConversionAdvice(Mlt::Producer *producer)
@@ -908,3 +911,82 @@ Mlt::Producer Util::openMltVirtualClip(const QString &path)
     }
     return Mlt::Producer();
 }
+
+bool Util::hasiPhoneAmbisonic(Mlt::Producer *producer)
+{
+    // iPhone 16 Pro has a 4 channel (spatial) audio stream with codec "apac" that causes failure.
+    // This is not limited to only iPhone 16 Pro, but I think most iPhones only record one usable audio track.
+    return producer && producer->is_valid()
+           && !::qstrcmp(producer->get("meta.media.1.stream.type"), "audio")
+           && QString(producer->get("meta.attr.com.apple.quicktime.model.markup")).contains("iPhone");
+}
+
+bool Util::installFlatpakWrappers(QWidget *parent)
+{
+    if (!Settings.askFlatpakWrappers())
+        return false;
+    QMessageBox dialog(QMessageBox::Question,
+                       qApp->applicationName(),
+                       parent->tr(
+                           "<p>Do you want use a Flatpak?</p>"
+                           "<p>Click <b>Yes</b> to install/update the Flatpak wrapper scripts "
+                           "in\n<b>Files > Home > Flatpaks</b>.</p>"
+                           "<p>Tip: Add <b><tt>~/Flatpaks</tt></b> to your <b><tt>$PATH</tt></b> "
+                           "to make them more "
+                           "convenient on the command line.</p>"),
+                       QMessageBox::No | QMessageBox::Yes,
+                       parent);
+    dialog.setCheckBox(new QCheckBox(parent->tr("Do not show this anymore.")));
+    dialog.setWindowModality(QmlApplication::dialogModality());
+    dialog.setDefaultButton(QMessageBox::Yes);
+    dialog.setEscapeButton(QMessageBox::No);
+    int r = dialog.exec();
+    if (dialog.checkBox()->isChecked())
+        Settings.setAskFlatpakWrappers(false);
+    if (r == QMessageBox::Yes) {
+        FlatpakWrapperGenerator flatpaks;
+        const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
+        auto home = QDir(ls.first());
+        const auto subdir = QStringLiteral("Flatpaks");
+        if (!home.cd(subdir)) {
+            if (home.mkdir(subdir))
+                home.cd(subdir);
+            else
+                return false;
+        }
+        flatpaks.setOutputDir(home.absolutePath());
+        flatpaks.setForce(true);
+        flatpaks.generateAllInstalled();
+        return true;
+    }
+    return false;
+}
+
+QString Util::getExecutable(QWidget *parent)
+{
+    QString dir;
+    QString filter;
+#if defined(Q_OS_WIN)
+    dir = QStringLiteral("C:/ProgramData/Microsoft/Windows/Start Menu/Programs");
+    filter = parent->tr("Executable Files (*.exe);;All Files (*)");
+#elif defined(Q_OS_MAC)
+    const auto ls = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
+    LOG_DEBUG() << ls;
+    dir = ls.last();
+#elif defined(Q_OS_LINUX)
+    if (Util::installFlatpakWrappers(parent)) {
+        const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
+        auto home = QDir(ls.first());
+        home.cd("Flatpaks");
+        dir = home.absolutePath();
+    } else {
+        dir = QStringLiteral("/usr/bin");
+    }
+#endif
+    return QFileDialog::getOpenFileName(MAIN.window(),
+                                        parent->tr("Choose Executable"),
+                                        dir,
+                                        filter,
+                                        nullptr,
+                                        Util::getFileDialogOptions());
+}
