@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2024 Meltytech, LLC
+ * Copyright (c) 2014-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,6 +89,9 @@ public:
     static double getAndroidFrameRate(Mlt::Producer *producer);
     static double getSuggestedFrameRate(Mlt::Producer *producer);
     static Mlt::Producer openMltVirtualClip(const QString &path);
+    static bool hasiPhoneAmbisonic(Mlt::Producer *producer);
+    static bool installFlatpakWrappers(QWidget *parent);
+    static QString getExecutable(QWidget *parent);
 };
 
 #endif // UTIL_H
