@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2024 Meltytech, LLC
+ * Copyright (c) 2012-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,9 +42,12 @@
 #include <QtWidgets>
 
 #include <limits>
+#include <unistd.h>
 
 static const auto kHandleSeconds = 15.0;
 static const auto kAbsoluteAudioIndex = "audio_index";
+static const auto kAudioMediaType = QLatin1String("audio");
+static const auto kVideoMediaType = QLatin1String("video");
 
 AvformatProducerWidget::AvformatProducerWidget(QWidget *parent)
     : QWidget(parent)
@@ -83,7 +86,7 @@ Mlt::Producer *AvformatProducerWidget::newProducer(Mlt::Profile &profile)
         QString warpspeed = QString::fromLatin1(tempProps.get("speed"));
 
         QString filename = Util::GetFilenameFromProducer(producer(), false);
-        QString s = QStringLiteral("%1:%2:%3").arg("timewarp").arg(warpspeed).arg(filename);
+        QString s = QStringLiteral("%1:%2:%3").arg("timewarp", warpspeed, filename);
         p = new Mlt::Producer(profile, s.toUtf8().constData());
         p->set(kShotcutProducerProperty, "avformat");
     }
@@ -242,6 +245,15 @@ void AvformatProducerWidget::reopen(Mlt::Producer *p)
 void AvformatProducerWidget::recreateProducer(bool getFrame)
 {
     Mlt::Producer *p = newProducer(MLT.profile());
+    if (!p || !p->is_valid()) {
+        // retry
+        QTimer::singleShot(1000, this, [&]() { p = newProducer(MLT.profile()); });
+    }
+    if (!p || !p->is_valid()) {
+        LOG_ERROR() << "failed to recreate producer for:"
+                           + Util::GetFilenameFromProducer(producer());
+        return;
+    }
     Util::passProducerProperties(m_producer.data(), p);
     Util::updateCaption(p);
     Mlt::Controller::copyFilters(*m_producer, *p);
@@ -267,6 +279,13 @@ void AvformatProducerWidget::recreateProducer(bool getFrame)
     } else {
         reopen(p);
     }
+    if (m_watcher) {
+        m_watcher.reset(new QFileSystemWatcher({Util::GetFilenameFromProducer(producer())}));
+        connect(m_watcher.get(),
+                &QFileSystemWatcher::fileChanged,
+                this,
+                &AvformatProducerWidget::on_reloadButton_clicked);
+    }
 }
 
 void AvformatProducerWidget::reloadProducerValues()
@@ -340,23 +359,14 @@ void AvformatProducerWidget::reloadProducerValues()
             QString width(m_producer->get(key.toLatin1().constData()));
             key = QStringLiteral("meta.media.%1.codec.height").arg(i);
             QString height(m_producer->get(key.toLatin1().constData()));
-            QString name = QStringLiteral("%1: %2x%3 %4")
-                               .arg(videoIndex + 1)
-                               .arg(width)
-                               .arg(height)
-                               .arg(codec);
+            QString name
+                = QStringLiteral("%1: %2x%3 %4").arg(videoIndex + 1).arg(width, height, codec);
             if (populateTrackCombos) {
                 if (ui->videoTrackComboBox->count() == 0)
                     ui->videoTrackComboBox->addItem(tr("None"), -1);
-#if LIBMLT_VERSION_INT >= ((7 << 16) + (19 << 8))
                 ui->videoTrackComboBox->addItem(name, videoIndex);
             }
             if (videoIndex == m_producer->get_int(kVideoIndexProperty)) {
-#else
-                ui->videoTrackComboBox->addItem(name, i);
-            }
-            if (i == m_producer->get_int(kVideoIndexProperty)) {
-#endif
                 key = QStringLiteral("meta.media.%1.codec.long_name").arg(i);
                 QString codec(m_producer->get(key.toLatin1().constData()));
                 ui->videoTableWidget->setItem(0, 1, new QTableWidgetItem(codec));
@@ -419,15 +429,9 @@ void AvformatProducerWidget::reloadProducerValues()
             if (populateTrackCombos) {
                 if (ui->audioTrackComboBox->count() == 0)
                     ui->audioTrackComboBox->addItem(tr("None"), -1);
-#if LIBMLT_VERSION_INT >= ((7 << 16) + (19 << 8))
                 ui->audioTrackComboBox->addItem(name, audioIndex);
             }
             if (QString::number(audioIndex) == m_producer->get(kAudioIndexProperty)) {
-#else
-                ui->audioTrackComboBox->addItem(name, i);
-            }
-            if (QString::number(i) == m_producer->get(kAudioIndexProperty)) {
-#endif
                 key = QStringLiteral("meta.media.%1.codec.long_name").arg(i);
                 QString codec(m_producer->get(key.toLatin1().constData()));
                 ui->audioTableWidget->setItem(0, 1, new QTableWidgetItem(codec));
@@ -923,11 +927,17 @@ void AvformatProducerWidget::on_reverseButton_clicked()
         }
 
         // transcode all streams except data, subtitles, and attachments
-        ffmpegArgs << "-map"
-                   << "0:V?"
-                   << "-map"
-                   << "0:a?"
-                   << "-map_metadata"
+        if (Util::hasiPhoneAmbisonic(m_producer.get()))
+            ffmpegArgs << "-map"
+                       << "0:V?"
+                       << "-map"
+                       << "0:a:0";
+        else
+            ffmpegArgs << "-map"
+                       << "0:V?"
+                       << "-map"
+                       << "0:a?";
+        ffmpegArgs << "-map_metadata"
                    << "0"
                    << "-ignore_unknown";
         if (ui->rangeComboBox->currentIndex())
@@ -1036,7 +1046,7 @@ void AvformatProducerWidget::on_reverseButton_clicked()
             break;
         }
         QFileInfo fi(resource);
-        path = path.arg(fi.completeBaseName()).arg(tr("Reversed"));
+        path = path.arg(fi.completeBaseName(), tr("Reversed"));
         QString filename = QmlApplication::getNextProjectFile(path);
         if (filename.isEmpty()) {
             filename = QFileDialog::getSaveFileName(this,
@@ -1075,9 +1085,7 @@ void AvformatProducerWidget::on_reverseButton_clicked()
             // Make a temporary file name for the ffmpeg job.
             QFileInfo fi(filename);
             QString tmpFileName = QStringLiteral("%1/%2 - XXXXXX.%3")
-                                      .arg(fi.path())
-                                      .arg(fi.completeBaseName())
-                                      .arg(ffmpegSuffix);
+                                      .arg(fi.path(), fi.completeBaseName(), ffmpegSuffix);
             QTemporaryFile tmp(tmpFileName);
             tmp.setAutoRemove(false);
             tmp.open();
@@ -1128,9 +1136,9 @@ void AvformatProducerWidget::on_actionExtractSubclip_triggered()
     QFileInfo fi(resource);
 
     path.append("/%1 - %2.%3");
-    path = path.arg(fi.completeBaseName()).arg(tr("Sub-clip")).arg(fi.suffix());
+    path = path.arg(fi.completeBaseName(), tr("Sub-clip"), fi.suffix());
     QString caption = tr("Extract Sub-clip...");
-    QString nameFilter = tr("%1 (*.%2);;All Files (*)").arg(fi.suffix()).arg(fi.suffix());
+    QString nameFilter = tr("%1 (*.%2);;All Files (*)").arg(fi.suffix(), fi.suffix());
     QString filename = QFileDialog::getSaveFileName(this,
                                                     caption,
                                                     path,
@@ -1447,10 +1455,8 @@ void AvformatProducerWidget::on_actionSetEquirectangular_triggered()
     // Get the location and file name for the report.
     QString caption = tr("Set Equirectangular Projection");
     QFileInfo info(Util::GetFilenameFromProducer(producer()));
-    QString directory = QStringLiteral("%1/%2 - ERP.%3")
-                            .arg(info.path())
-                            .arg(info.completeBaseName())
-                            .arg(info.suffix());
+    QString directory
+        = QStringLiteral("%1/%2 - ERP.%3").arg(info.path(), info.completeBaseName(), info.suffix());
     QString filePath = QFileDialog::getSaveFileName(&MAIN,
                                                     caption,
                                                     directory,
@@ -1589,3 +1595,108 @@ void AvformatProducerWidget::on_actionShowInFiles_triggered()
 {
     emit showInFiles(Util::GetFilenameFromProducer(producer()));
 }
+
+void AvformatProducerWidget::on_openWithButton_clicked()
+{
+    const auto filePath = Util::GetFilenameFromProducer(producer());
+    QMenu menu;
+    auto action = new QAction(tr("System Default"), this);
+    menu.addAction(action);
+    connect(action, &QAction::triggered, this, [=]() {
+        LOG_DEBUG() << filePath;
+#if defined(Q_OS_WIN)
+        const auto scheme = QLatin1String("file:///");
+#else
+        const auto scheme = QLatin1String("file://");
+#endif
+        if (QDesktopServices::openUrl({scheme + filePath, QUrl::TolerantMode})) {
+            m_watcher.reset(new QFileSystemWatcher({filePath}));
+            connect(m_watcher.get(),
+                    &QFileSystemWatcher::fileChanged,
+                    this,
+                    &AvformatProducerWidget::on_reloadButton_clicked);
+        }
+    });
+
+    menu.addSeparator();
+    // custom options
+    auto programs = Settings.filesOpenOther(mediaType());
+    for (const auto &program : programs) {
+        auto action = menu.addAction(QFileInfo(program).baseName(), this, [=]() {
+            LOG_DEBUG() << program << filePath;
+            if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
+                m_watcher.reset(new QFileSystemWatcher({filePath}));
+                connect(m_watcher.get(),
+                        &QFileSystemWatcher::fileChanged,
+                        this,
+                        &AvformatProducerWidget::on_reloadButton_clicked);
+            }
+        });
+        action->setObjectName(program);
+        menu.addAction(action);
+    }
+    menu.addSeparator();
+
+    action = new QAction(tr("Other..."), this);
+    menu.addAction(action);
+    connect(action, &QAction::triggered, this, &AvformatProducerWidget::onOpenOtherAdd);
+
+    action = new QAction(tr("Remove..."), this);
+    menu.addAction(action);
+    connect(action, &QAction::triggered, this, &AvformatProducerWidget::onOpenOtherRemove);
+
+    menu.exec(ui->openWithButton->mapToGlobal(QPoint(0, 0)));
+}
+
+void AvformatProducerWidget::onOpenOtherAdd()
+{
+    LOG_DEBUG();
+    const auto filePath = Util::GetFilenameFromProducer(producer());
+    if (filePath.isEmpty())
+        return;
+
+    const auto program = Util::getExecutable(&MAIN);
+    if (!program.isEmpty()) {
+        LOG_DEBUG() << program << filePath;
+        if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
+            Settings.setFilesOpenOther(mediaType(), program);
+            m_watcher.reset(new QFileSystemWatcher({filePath}));
+            connect(m_watcher.get(),
+                    &QFileSystemWatcher::fileChanged,
+                    this,
+                    &AvformatProducerWidget::on_reloadButton_clicked);
+        }
+    }
+}
+
+void AvformatProducerWidget::onOpenOtherRemove()
+{
+    const auto mt = mediaType();
+    auto ls = Settings.filesOpenOther(mt);
+    ls.sort(Qt::CaseInsensitive);
+    QStringList programs;
+    std::for_each(ls.begin(), ls.end(), [&](const QString &s) {
+        programs << QDir::toNativeSeparators(s);
+    });
+    ListSelectionDialog dialog(programs, this);
+    dialog.setWindowModality(QmlApplication::dialogModality());
+    dialog.setWindowTitle(tr("Remove From Open With"));
+    if (QDialog::Accepted == dialog.exec()) {
+        for (auto program : dialog.selection()) {
+            program = QDir::fromNativeSeparators(program);
+            Settings.removeFilesOpenOther(mt, program);
+        }
+    }
+}
+
+QString AvformatProducerWidget::mediaType()
+{
+    if (fps() > 0.0 && fps() != 90000.0)
+        return kVideoMediaType;
+    return kAudioMediaType;
+}
+
+void AvformatProducerWidget::on_reloadButton_clicked()
+{
+    recreateProducer();
+}
