@@ -18,12 +18,13 @@
 
 #include "pulseaudiowidget.h"
 #include "ui_pulseaudiowidget.h"
-#include "util.h"
-#include "shotcut_mlt_properties.h"
 
-PulseAudioWidget::PulseAudioWidget(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::PulseAudioWidget)
+#include "shotcut_mlt_properties.h"
+#include "util.h"
+
+PulseAudioWidget::PulseAudioWidget(QWidget *parent)
+    : QWidget(parent)
+    , ui(new Ui::PulseAudioWidget)
 {
     ui->setupUi(this);
     Util::setColorsToHighlight(ui->label);
@@ -34,9 +35,9 @@ PulseAudioWidget::~PulseAudioWidget()
     delete ui;
 }
 
-Mlt::Producer* PulseAudioWidget::newProducer(Mlt::Profile& profile)
+Mlt::Producer *PulseAudioWidget::newProducer(Mlt::Profile &profile)
 {
-    Mlt::Producer* p = new Mlt::Producer(profile, "pulse:default?name=Shotcut");
+    Mlt::Producer *p = new Mlt::Producer(profile, "pulse:default?name=Shotcut");
     p->set(kBackgroundCaptureProperty, 1);
     p->set(kShotcutCaptionProperty, "PulseAudio");
     return p;
