@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,11 +16,14 @@
  */
 
 #include "timespinbox.h"
+
 #include "mltcontroller.h"
-#include <QRegularExpressionValidator>
-#include <QKeyEvent>
+#include "settings.h"
+
 #include <QFontDatabase>
 #include <QGuiApplication>
+#include <QKeyEvent>
+#include <QRegularExpressionValidator>
 
 TimeSpinBox::TimeSpinBox(QWidget *parent)
     : QSpinBox(parent)
@@ -28,13 +31,16 @@ TimeSpinBox::TimeSpinBox(QWidget *parent)
     setLineEdit(new TimeSpinBoxLineEdit);
     setRange(0, INT_MAX);
     setAlignment(Qt::AlignRight);
-    m_validator = new QRegularExpressionValidator(
-        QRegularExpression("^\\s*(\\d*:){0,2}(\\d*[.;:])?\\d*\\s*$"), this);
+    m_validator = new QRegularExpressionValidator(QRegularExpression(
+                                                      "^\\s*(\\d*:){0,2}(\\d*[.;:])?\\d*\\s*$"),
+                                                  this);
     setValue(0);
     QFont font = QFontDatabase::systemFont(QFontDatabase::FixedFont);
     font.setPointSize(QGuiApplication::font().pointSize());
     setFont(font);
     setFixedWidth(fontMetrics().boundingRect("_HHH:MM:SS;FFF_").width());
+
+    connect(&Settings, &ShotcutSettings::timeFormatChanged, this, [&]() { setValue(value()); });
 }
 
 QValidator::State TimeSpinBox::validate(QString &input, int &pos) const
@@ -55,9 +61,9 @@ int TimeSpinBox::valueFromText(const QString &text) const
 QString TimeSpinBox::textFromValue(int val) const
 {
     if (MLT.producer() && MLT.producer()->is_valid()) {
-        return MLT.producer()->frames_to_time(val);
+        return MLT.producer()->frames_to_time(val, Settings.timeFormat());
     } else {
-        return Mlt::Producer(MLT.profile(), "color", "").frames_to_time(val);
+        return Mlt::Producer(MLT.profile(), "color", "").frames_to_time(val, Settings.timeFormat());
     }
     return QString();
 }
@@ -76,12 +82,10 @@ void TimeSpinBox::keyPressEvent(QKeyEvent *event)
     }
 }
 
-
 TimeSpinBoxLineEdit::TimeSpinBoxLineEdit(QWidget *parent)
     : QLineEdit(parent)
     , m_selectOnMousePress(false)
-{
-}
+{}
 
 void TimeSpinBoxLineEdit::focusInEvent(QFocusEvent *event)
 {
@@ -106,4 +110,3 @@ void TimeSpinBoxLineEdit::mousePressEvent(QMouseEvent *event)
         m_selectOnMousePress = false;
     }
 }
-
